@@ -2,7 +2,6 @@ import requests
 from requests.packages.urllib3.exceptions import InsecureRequestWarning
 from .auth import EncryptionClient
 from .const import GENERIC_PAYLOAD, LOGIN_PAYLOAD, HEADERS, NEXT_DAY_TIMESTAMP, TODAY_TIMESTAMP,LOGIN_CHECK_PAYLOAD,WS_PAYLOAD,JWT_PAYLOAD,JWT_HEADERS
-from .conf import APP_SOURCE
 from .order import Order, bo_co_order, OrderType, OrderFor
 from .logging import log_response
 import datetime
@@ -35,6 +34,8 @@ class FivePaisaClient:
     HISTORICAL_DATA_ROUTE="https://openapi.5paisa.com/historical/"
 
     IDEAS_ROUTE="https://openapi.5paisa.com/VendorsAPI/Service1.svc/TraderIDEAs"
+
+    TRADEBOOK_ROUTE="https://Openapi.5paisa.com/VendorsAPI/Service1.svc/V1/TradeBook"
     
     MARGIN_REQUEST_CODE = "5PMarginV3"
     ORDER_BOOK_REQUEST_CODE = "5POrdBkV2"
@@ -42,7 +43,10 @@ class FivePaisaClient:
     POSITIONS_REQUEST_CODE = "5PNPNWV1"
     IDEAS_REQUEST_CODE ="5PTraderIDEAs"
 
-    def __init__(self, email=None, passwd=None, dob=None):
+
+   
+
+    def __init__(self, email=None, passwd=None, dob=None,cred=None):
         """
         Main constructor for client.
         Expects user's email, password and date of birth in YYYYMMDD format.
@@ -61,9 +65,17 @@ class FivePaisaClient:
         self.Aspx_auth = None
         self.web_url= None
         self.session = requests.Session()
+        self.APP_SOURCE=cred["APP_SOURCE"]
+        self.APP_NAME=cred["APP_NAME"]
+        self.USER_ID=cred["USER_ID"]
+        self.PASSWORD=cred["PASSWORD"]
+        self.USER_KEY=cred["USER_KEY"]
+        self.ENCRYPTION_KEY=cred["ENCRYPTION_KEY"]
+        
+        
 
     def login(self):
-        encryption_client = EncryptionClient()
+        encryption_client = EncryptionClient(self.ENCRYPTION_KEY)
         secret_email = encryption_client.encrypt(self.email)
         secret_passwd = encryption_client.encrypt(self.passwd)
         secret_dob = encryption_client.encrypt(self.dob)
@@ -71,6 +83,10 @@ class FivePaisaClient:
         self.login_payload["body"]["Password"] = secret_passwd
         self.login_payload["body"]["My2PIN"] = secret_dob
         self.login_payload["head"]["requestCode"] = "5PLoginV3"
+        self.login_payload["head"]["appName"] = self.APP_NAME
+        self.login_payload["head"]["key"] = self.USER_KEY
+        self.login_payload["head"]["userId"] = self.USER_ID
+        self.login_payload["head"]["password"] = self.PASSWORD  
         res = self._login_request(self.LOGIN_ROUTE)
         message = res["body"]["Message"]
         if message == "":
@@ -108,6 +124,10 @@ class FivePaisaClient:
 
     def _user_info_request(self, data_type):
         payload = GENERIC_PAYLOAD
+        payload["head"]["appName"] = self.APP_NAME
+        payload["head"]["key"] = self.USER_KEY
+        payload["head"]["userId"] = self.USER_ID
+        payload["head"]["password"] = self.PASSWORD
         payload["body"]["ClientCode"] = self.client_code
         return_type = ""
         if data_type == "MARGIN":
@@ -146,7 +166,10 @@ class FivePaisaClient:
     def order_request(self, req_type) -> None:
 
         self.payload["body"]["ClientCode"] = self.client_code
-
+        self.payload["head"]["appName"] = self.APP_NAME
+        self.payload["head"]["key"] = self.USER_KEY
+        self.payload["head"]["userId"] = self.USER_ID
+        self.payload["head"]["password"] = self.PASSWORD 
         if req_type == "OP":
             url = self.ORDER_PLACEMENT_ROUTE
             self.payload["head"]["requestCode"] = "5POrdReq"
@@ -172,6 +195,9 @@ class FivePaisaClient:
         elif req_type == "MD":
             url = self.MARKET_DEPTH_ROUTE
             self.payload["head"]["requestCode"] = "5PMD"
+        elif req_type == "TB":
+            url = self.TRADEBOOK_ROUTE
+            self.payload["head"]["requestCode"] = "5PTrdBkV1"
         
             
         else:
@@ -210,6 +236,10 @@ class FivePaisaClient:
         return self.order_request("MF")
 
     def set_payload(self, order: Order) -> None:
+        self.payload["head"]["appName"] = self.APP_NAME
+        self.payload["head"]["key"] = self.USER_KEY
+        self.payload["head"]["userId"] = self.USER_ID
+        self.payload["head"]["password"] = self.PASSWORD 
         self.payload["body"]["OrderFor"] = order.order_for
         self.payload["body"]["Exchange"] = order.exchange
         self.payload["body"]["ExchangeType"] = order.exchange_segment
@@ -235,13 +265,18 @@ class FivePaisaClient:
         self.payload["body"]["ValidTillDate"] = f"/Date({NEXT_DAY_TIMESTAMP})/"
         self.payload["body"]["TradedQty"] = order.traded_qty
         self.payload["body"]["OrderRequesterCode"] = self.client_code
-        self.payload["body"]["AppSource"] = APP_SOURCE
+        self.payload["body"]["AppSource"] = self.APP_SOURCE
         self.payload["body"]["iOrderValidity"] = order.order_validity
         
     def set_payload_bo(self,boco:bo_co_order)-> None:
         """
             this is for bo-co order placement
         """
+        
+        self.payload["head"]["appName"] = self.APP_NAME
+        self.payload["head"]["key"] = self.USER_KEY
+        self.payload["head"]["userId"] = self.USER_ID
+        self.payload["head"]["password"] = self.PASSWORD 
         self.payload["body"]["RequestType"] = boco.RequestType
         self.payload["body"]["BuySell"] = boco.BuySell
         self.payload["body"]["Qty"] = boco.Qty
@@ -265,7 +300,7 @@ class FivePaisaClient:
         self.payload["body"]["LocalOrderIDSL"] = boco.LocalOrderIDSL
         self.payload["body"]["LocalOrderIDLimit"] = boco.LocalOrderIDLimit
         self.payload["body"]["PublicIP"] = boco.public_ip
-        self.payload["body"]["AppSource"] = boco.app_source
+        self.payload["body"]["AppSource"] = self.APP_SOURCE
         self.payload["body"]["TradedQty"] = boco.traded_qty
 
     def place_order(self, order: Order):
@@ -318,7 +353,7 @@ class FivePaisaClient:
     def Streming_data(self,wsPayload : dict):
         self.web_url=f'wss://openfeed.5paisa.com/Feeds/api/chat?Value1={self.Jwt_token}|{self.client_code}'
         auth=self.Login_check()
-
+        
         def on_message(ws, message):
             print(message)
         
@@ -343,6 +378,8 @@ class FivePaisaClient:
         ws.run_forever()
         
     def Login_check(self):
+        self.login_check_payload["head"]["key"]=self.USER_KEY
+        self.login_check_payload["head"]["appName"]=self.APP_NAME
         self.login_check_payload["head"]["LoginId"]=self.client_code
         self.login_check_payload["body"]["RegistrationID"]=self.Jwt_token
         url=self.LOGIN_CHECK_ROUTE
@@ -409,6 +446,11 @@ class FivePaisaClient:
             message ="You don't have an active Ultra-Trader-Pack. Please subscribe to it to avail the services."
             return message
 
+
+    def get_tradebook(self):
+        return self.order_request("TB")
+        
+
         
         
     
