@@ -2,13 +2,14 @@
 
 from py5paisa import FivePaisaClient
 from py5paisa.order import Order,bo_co_order
-from .conf import user,passw,dob
 
-Client=FivePaisaClient(email=user, passwd=passw, dob=dob)
-Client.login()
 
 class strategies:
 
+    def __init__(self,user=None,passw=None,dob=None,cred=None):
+        self.Client=FivePaisaClient(email=user, passwd=passw, dob=dob,cred=cred)
+        self.Client.login()
+        
     def get_scripcode(self,symbol,strike,expiry,opt):
         month={
             "01":'JAN',
@@ -31,7 +32,8 @@ class strategies:
         strike_f="{:.2f}".format(float(strike))
         sym=f'{symbol} {date} {mon} {year} {opt} {strike_f}'
         req=[{"Exch":"N","ExchType":"D","Symbol":sym,"Expiry":expiry,"StrikePrice":strike,"OptionType":opt}]
-        res=Client.fetch_market_feed(req)
+
+        res=self.Client.fetch_market_feed(req)
         token=res['Data'][0]['Token']
         return token
 
@@ -55,7 +57,7 @@ class strategies:
          
         for s in scrip:
             test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True,)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             print(order_status)
             if order_status['Message']=='Success':
                 continue
@@ -79,7 +81,7 @@ class strategies:
          
         for s in scrip:
             test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
@@ -99,7 +101,7 @@ class strategies:
          
         for s in scrip:
             test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
@@ -122,7 +124,7 @@ class strategies:
          
         for s in scrip:
             test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
@@ -149,14 +151,14 @@ class strategies:
             sell_scrip.append(sc)
         for s in buy_scrip:
             test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
                 break
         for s in sell_scrip:
             test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
@@ -186,14 +188,14 @@ class strategies:
             sell_scrip.append(sc)
         for s in buy_scrip:
             test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True,)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
                 break
         for s in sell_scrip:
             test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
+            order_status=self.Client.place_order(test_order)
             if order_status['Message']=='Success':
                 continue
             else:
@@ -213,9 +215,9 @@ class strategies:
             scrip.append(sc)
             i=i+1 
         test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=scrip[0], quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-        order_status=Client.place_order(test_order)
+        order_status=self.Client.place_order(test_order)
         test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=scrip[1], quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-        order_status=Client.place_order(test_order)
+        order_status=self.Client.place_order(test_order)
     
     def put_calendar(self,symbol,strike,qty,expiry,intra):
         self.symbol=symbol
@@ -231,108 +233,6 @@ class strategies:
             scrip.append(sc)
             i=i+1 
         test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=scrip[0], quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-        order_status=Client.place_order(test_order)
+        order_status=self.Client.place_order(test_order)
         test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=scrip[1], quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-        order_status=Client.place_order(test_order)
-    def call_ladder(self,symbol,buy_strike,sell_strike,qty,expiry,intra):
-        sell_strike.sort()
-        self.symbol=symbol
-        self.buy_strike=buy_strike
-        self.sell_strike=sell_strike
-        self.qty=qty
-        self.expiry=expiry
-        self.intra=intra
-        buy_scrip=[]
-        sell_scrip=[]
-        j=0
-        options =['CE','CE']
-        buy_scrip.append(self.get_scripcode(self.symbol,self.buy_strike,self.expiry,options[0]))
-        for opt in options:
-            sc=self.get_scripcode(self.symbol,self.sell_strike[j],self.expiry,opt)
-            j=j+1
-            sell_scrip.append(sc)
-            
-        for s in buy_scrip:
-            test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True,)
-            order_status=Client.place_order(test_order)
-            if order_status['Message']=='Success':
-                continue
-            else:
-                break
-        for s in sell_scrip:
-            test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
-            if order_status['Message']=='Success':
-                continue
-            else:
-                break
-
-    def put_ladder(self,symbol,buy_strike,sell_strike,qty,expiry,intra):
-        sell_strike.sort()
-        self.symbol=symbol
-        self.buy_strike=buy_strike
-        self.sell_strike=sell_strike
-        self.qty=qty
-        self.expiry=expiry
-        self.intra=intra
-        buy_scrip=[]
-        sell_scrip=[]
-        j=0
-        options =['PE','PE']
-        buy_scrip.append(self.get_scripcode(self.symbol,self.buy_strike,self.expiry,options[0]))
-        for opt in options:
-            sc=self.get_scripcode(self.symbol,self.sell_strike[j],self.expiry,opt)
-            j=j+1
-            sell_scrip.append(sc)
-        for s in buy_scrip:
-            test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True,)
-            order_status=Client.place_order(test_order)
-            if order_status['Message']=='Success':
-                continue
-            else:
-                break
-        for s in sell_scrip:
-            test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
-            if order_status['Message']=='Success':
-                continue
-            else:
-                break
-
-    def ladder(self,symbol,buy_strike,sell_strike,qty,expiry,intra):
-        buy_strike.sort()
-        sell_strike.sort()
-        self.symbol=symbol
-        self.buy_strike=buy_strike
-        self.sell_strike=sell_strike
-        self.qty=qty
-        self.expiry=expiry
-        self.intra=intra
-        buy_scrip=[]
-        sell_scrip=[]
-        i=0
-        j=0
-        options =['PE','CE']
-        for opt in options:
-            sc=self.get_scripcode(self.symbol,self.buy_strike[i],self.expiry,opt)
-            i=i+1
-            buy_scrip.append(sc)
-        for opt in options:
-            sell_scrip.append(self.get_scripcode(self.symbol,self.sell_strike[j],self.expiry,opt))
-            sell_scrip.append(self.get_scripcode(self.symbol,self.sell_strike[j+1],self.expiry,opt))
-            j=j+2
-        for s in buy_scrip:
-            test_order = Order(order_type='B',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True,)
-            order_status=Client.place_order(test_order)
-            if order_status['Message']=='Success':
-                continue
-            else:
-                break
-        for s in sell_scrip:
-            test_order = Order(order_type='S',exchange='N',exchange_segment='D', scrip_code=s, quantity=qty, price=0,is_intraday=self.intraday(self.intra),atmarket=True)
-            order_status=Client.place_order(test_order)
-            if order_status['Message']=='Success':
-                continue
-            else:
-                break
-    
+        order_status=self.Client.place_order(test_order)
